@@ -31,8 +31,8 @@ class CoCoPeriphery(Dragon32Periphery):
     http://sourceforge.net/p/toolshed/code/ci/default/tree/cocoroms/bas.asm
     http://www.lomont.org/Software/Misc/CoCo/Lomont_CoCoHardware_2.pdf
     """
-    def __init__(self, cfg, cpu, memory, display_queue, user_input_queue):
-        super(CoCoPeriphery, self).__init__(cfg, cpu, memory, display_queue, user_input_queue)
+    def __init__(self, cfg, cpu, memory, display_callback, user_input_queue):
+        super(CoCoPeriphery, self).__init__(cfg, cpu, memory, display_callback, user_input_queue)
 #         self.read_byte_func_map.update({
 #             0xc000: self.no_dos_rom,
 #         })
