@@ -51,7 +51,7 @@ class PIA_register(object):
         self.irq = 0x00
 
     def set(self, value):
-        log.error("\t set %s to $%02x %s", self.name, value, '{0:08b}'.format(value))
+        log.debug("\t set %s to $%02x %s", self.name, value, '{0:08b}'.format(value))
         self.value = value
 
     def get(self):
@@ -98,7 +98,8 @@ class PIA(object):
         self.user_input_queue = user_input_queue
 
         self.pia_0_A_register = PIA_register("PIA0 A")
-        self.pia_0_B_register = PIA_register("PIA0 B")
+        self.pia_0_B_data = PIA_register("PIA0 B data register $ff02")
+        self.pia_0_B_control = PIA_register("PIA0 B control register $ff03")
 
         self.pia_1_A_register = PIA_register("PIA1 A")
         self.pia_1_B_register = PIA_register("PIA1 B")
@@ -143,7 +144,8 @@ class PIA(object):
     def reset(self):
         log.critical("PIA reset()")
         self.pia_0_A_register.reset()
-        self.pia_0_B_register.reset()
+        self.pia_0_B_data.reset()
+        self.pia_0_B_control.reset()
         self.pia_1_A_register.reset()
         self.pia_1_B_register.reset()
 
@@ -184,7 +186,7 @@ class PIA(object):
 
     def read_PIA1_B_data(self, cpu_cycles, op_address, address):
         """ read from 0xff22 -> PIA 1 B side Data reg. """
-        log.error("TODO: read from 0xff22 -> PIA 1 B side Data reg.")
+        log.debug("TODO: read from 0xff22 -> PIA 1 B side Data reg.")
         return 0x00
 
     def read_PIA1_B_control(self, cpu_cycles, op_address, address):
@@ -206,8 +208,9 @@ class PIA(object):
 
     def write_PIA1_B_data(self, cpu_cycles, op_address, address, value):
         """ write to 0xff22 -> PIA 1 B side Data reg. """
-        log.error(
-            "TODO: write $%02x to 0xff22 -> PIA 1 B side Data reg.", value)
+        log.debug(
+            "TODO: write $%02x to 0xff22 -> PIA 1 B side Data reg.", value
+        )
 
     def write_PIA1_B_control(self, cpu_cycles, op_address, address, value):
         """ write to 0xff23 -> PIA 1 B side Control reg. """
@@ -240,7 +243,7 @@ class PIA(object):
         bit 1 | PA1 | keyboard matrix row 2 & left  joystick switch 1
         bit 0 | PA0 | keyboard matrix row 1 & right joystick switch 1
         """
-        pia0b = self.pia_0_B_register.get()  # $ff02
+        pia0b = self.pia_0_B_data.get()  # $ff02
 
         # FIXME: Find a way to handle CoCo and Dragon in the same way!
         if self.cfg.CONFIG_NAME == COCO2B:
@@ -370,8 +373,8 @@ class PIA(object):
 
         bits 0-7 also printer data lines
         """
-        value = self.pia_0_B_register.get()  # $ff02
-        log.error(
+        value = self.pia_0_B_data.get()  # $ff02
+        log.debug(
             "%04x| read $%04x (PIA 0 B side Data reg.) send $%02x (%s) back.\t|%s",
             op_address, address, value, byte2bit_string(value),
             self.cfg.mem_info.get_shortest(op_address)
@@ -380,19 +383,19 @@ class PIA(object):
 
     def write_PIA0_B_data(self, cpu_cycles, op_address, address, value):
         """ write to 0xff02 -> PIA 0 B side Data reg. """
-        log.critical(
+        log.debug(
 #        log.info(
             "%04x| write $%02x (%s) to $%04x -> PIA 0 B side Data reg.\t|%s",
             op_address, value, byte2bit_string(value),
             address, self.cfg.mem_info.get_shortest(op_address)
         )
-        self.pia_0_B_register.set(value)
+        self.pia_0_B_data.set(value)
 
     def read_PIA0_B_control(self, cpu_cycles, op_address, address):
         """
         read from 0xff03 -> PIA 0 B side Control reg.
         """
-        value = self.pia_0_B_register.get()
+        value = self.pia_0_B_control.get()
         log.error(
             "%04x| read $%04x (PIA 0 B side Control reg.) send $%02x (%s) back.\t|%s",
             op_address, address, value, byte2bit_string(value),
@@ -421,22 +424,6 @@ class PIA(object):
             address, self.cfg.mem_info.get_shortest(op_address)
         )
 
-        if is_bit_set(value, bit=0):
-            log.critical(
-                "%04x| write $%02x (%s) to $%04x -> VSYNC IRQ: enable\t|%s",
-                op_address, value, byte2bit_string(value),
-                address, self.cfg.mem_info.get_shortest(op_address)
-            )
-            self.cpu.irq_enabled = True
-            value = set_bit(value, bit=7)
-        else:
-            log.critical(
-                "%04x| write $%02x (%s) to $%04x -> VSYNC IRQ: disable\t|%s",
-                op_address, value, byte2bit_string(value),
-                address, self.cfg.mem_info.get_shortest(op_address)
-            )
-            self.cpu.irq_enabled = False
-
         if is_bit_set(value, bit=0):
             log.critical(
                 "%04x| write $%02x (%s) to $%04x -> VSYNC IRQ: enable\t|%s",
@@ -454,11 +441,11 @@ class PIA(object):
             self.cpu.irq_enabled = False
 
         if not is_bit_set(value, bit=2):
-            self.pia_0_B_register.select_pdr()
+            self.pia_0_B_control.select_pdr()
         else:
-            self.pia_0_B_register.deselect_pdr()
+            self.pia_0_B_control.deselect_pdr()
 
-        self.pia_0_B_register.set(value)
+        self.pia_0_B_control.set(value)
 
 #------------------------------------------------------------------------------
 
