@@ -89,12 +89,12 @@ class Dragon32Cfg(BaseConfig):
         self.memory_byte_middlewares = {
             # (start_addr, end_addr): (read_func, write_func)
 #             (0x0152, 0x0159): (None, self.keyboard_matrix_state),
-            (0x0115, 0x0119): (self.rnd_seed_read, self.rnd_seed_write),
-            (0x0112, 0x0113): (self.timer_value_read, self.timer_value_write),
+#             (0x0115, 0x0119): (self.rnd_seed_read, self.rnd_seed_write),
+#             (0x0112, 0x0113): (self.timer_value_read, self.timer_value_write),
         }
         self.memory_word_middlewares = {
-            (0x0019, 0x001F): (None, self.basic_addresses_write),
-            (0x0112, 0x0113): (self.timer_value_read_word, self.timer_value_write_word),
+            # (0x0019, 0x001F): (None, self.basic_addresses_write),
+            # (0x0112, 0x0113): (self.timer_value_read_word, self.timer_value_write_word),
         }
 
     def keyboard_matrix_state(self, cpu, addr, value):
