@@ -35,27 +35,25 @@ except ImportError:
     import thread as _thread
 
 import inspect
-import os
-import socket
+import logging
 import sys
 import threading
 import time
 import warnings
-import logging
 
-from dragonpy.MC6809data.MC6809_data_raw2 import (
-    OP_DATA, REG_A, REG_B, REG_CC, REG_D, REG_DP, REG_PC,
-    REG_S, REG_U, REG_X, REG_Y
-)
+
 from dragonpy.core.cpu_control_server import start_http_control_server
-from dragonpy.cpu_utils.MC6809_registers import (
+from dragonpy.components.cpu_utils.MC6809_registers import (
     ValueStorage8Bit, ConcatenatedAccumulator,
     ValueStorage16Bit, ConditionCodeRegister, UndefinedRegister
 )
-from dragonpy.cpu_utils.instruction_caller import OpCollection
+from dragonpy.components.cpu_utils.instruction_caller import OpCollection
 from dragonpy.utils.bits import is_bit_set, get_bit
 from dragonpy.utils.byte_word_values import signed8, signed16, signed5
-from dragonpy.utils.simple_debugger import print_exc_plus
+from dragonpy.components.MC6809data.MC6809_op_data import (
+    REG_A, REG_B, REG_CC, REG_D, REG_DP, REG_PC,
+    REG_S, REG_U, REG_X, REG_Y
+)
 
 
 log = logging.getLogger(__name__)
@@ -239,7 +237,7 @@ class CPU(object):
     ####
 
     def reset(self):
-#        log.info("$%x CPU reset:" % self.program_counter)
+        log.info("%04x| CPU reset:", self.program_counter.get())
 
         self.last_op_address = 0
 
@@ -263,9 +261,11 @@ class CPU(object):
 #         log.debug("\tset PC to $%x" % self.cfg.RESET_VECTOR)
 #         self.program_counter = self.cfg.RESET_VECTOR
 
-#        log.info("\tread word from $%x" % self.cfg.RESET_VECTOR)
+        log.info("\tread reset vector from $%04x", self.RESET_VECTOR)
         ea = self.memory.read_word(self.RESET_VECTOR)
-#        log.info("\tset PC to $%x" % (ea))
+        log.info("\tset PC to $%04x" % ea)
+        if ea == 0x0000:
+            log.critical("Reset vector is $%04x ??? ROM loading in the right place?!?", ea)
         self.program_counter.set(ea)
 
     ####
@@ -375,10 +375,10 @@ class CPU(object):
         >>> calc_new_count(burst_count=100, current_value=20, target_value=40)
         150
         """
-        log.critical(
-            "%i op count current: %.4f target: %.4f",
-            self.burst_op_count, current_value, target_value
-        )
+        # log.critical(
+        #     "%i op count current: %.4f target: %.4f",
+        #     self.burst_op_count, current_value, target_value
+        # )
         try:
             new_burst_count = float(burst_count) / float(current_value) * target_value
             new_burst_count += 1 # At least we need one loop ;)
@@ -2529,9 +2529,9 @@ class CPU(object):
     irq_enabled = False
     def irq(self):
         if not self.irq_enabled or self.cc.I == 1:
-            log.critical("$%04x *** IRQ, ignore!\t%s" % (
-                self.program_counter.get(), self.cc.get_info
-            ))
+            # log.critical("$%04x *** IRQ, ignore!\t%s" % (
+            #     self.program_counter.get(), self.cc.get_info
+            # ))
             return
 
         if self.cc.E:
@@ -2540,9 +2540,9 @@ class CPU(object):
             self.push_firq_registers()
 
         ea = self.memory.read_word(self.IRQ_VECTOR)
-        log.critical("$%04x *** IRQ, set PC to $%04x\t%s" % (
-            self.program_counter.get(), ea, self.cc.get_info
-        ))
+        # log.critical("$%04x *** IRQ, set PC to $%04x\t%s" % (
+        #     self.program_counter.get(), ea, self.cc.get_info
+        # ))
         self.program_counter.set(ea)
 
     def push_irq_registers(self):
