@@ -51,6 +51,8 @@ class Memory(object):
 
         assert not hasattr(cfg, "ram"), "cfg.ram is deprecated! Remove it from: %s" % self.cfg.__class__.__name__
 
+        assert not hasattr(cfg, "DEFAULT_ROM"), "cfg.DEFAULT_ROM must be converted to DEFAULT_ROMS tuple in %s" % self.cfg.__class__.__name__
+
         assert self.RAM_SIZE + self.RAM_SIZE <= self.INTERNAL_SIZE, "%s Bytes < %s Bytes" % (
             self.RAM_SIZE + self.RAM_SIZE, self.INTERNAL_SIZE
         )
@@ -69,11 +71,7 @@ class Memory(object):
 
         if cfg and cfg.rom_cfg:
             for romfile in cfg.rom_cfg:
-                self.load_file(
-                    address=romfile.address,
-                    filename=romfile.filepath,
-                    max_size=romfile.max_size
-                )
+                self.load_file(romfile)
 
         self._read_byte_callbacks = {}
         self._read_word_callbacks = {}
@@ -177,33 +175,10 @@ class Memory(object):
         for ea, datum in enumerate(data, address):
             self._mem[ea] = datum
 
-    def load_file(self, address, filename, max_size=None):
-        # TODO: Use self.load !
-        log.critical("Load ROM file %r to $%04x", filename, address)
-        with open(filename, "rb") as f:
-            filesize = os.stat(filename).st_size
-            for offset, datum in enumerate(f.read()):
-                if max_size and offset > max_size:
-                    log.critical("Load only $%04x (dez.: %i) Bytes - file size is $%04x (dez.: %i) Bytes",
-                        max_size, max_size, filesize, filesize
-                    )
-                    break
-
-                index = address + offset
-                if six.PY2:
-                    datum = ord(datum)
-
-#                 log.critical("$%04x - $%02x", index, datum)
-                try:
-                    self._mem[index] = datum
-                except IndexError:
-                    log.error("Error: File %s $%04x (dez.: %i) Bytes is bigger than: $%04x" % (
-                        filename, filesize, filesize, index
-                    ))
-                    break
-        log.info("read $%04x (dez.: %i) Bytes from %r into ROM $%04x-$%04x",
-            offset, offset, filename, address, (address + offset)
-        )
+    def load_file(self, romfile):
+        data = romfile.get_data()
+        self.load(romfile.address, data)
+        log.critical("Load ROM file %r to $%04x", romfile.filepath, romfile.address)
 
     #---------------------------------------------------------------------------
 
@@ -331,7 +306,7 @@ class Memory(object):
         return [self.read_byte(addr) for addr in xrange(start, end)]
 
     def iter_bytes(self, start, end):
-        for addr in xrange(start, end + 1):
+        for addr in xrange(start, end):
             yield addr, self.read_byte(addr)
 
     def get_dump(self, start, end):
