@@ -8,7 +8,8 @@
 """
 
 from __future__ import absolute_import, division, print_function
-
+from dragonlib.utils import six
+xrange = six.moves.xrange
 
 import logging
 import sys
@@ -45,7 +46,7 @@ class BaseDragon32TestCase(BaseCPUTestCase):
 
 class Test6809_Register(BaseCPUTestCase):
     def test_registerA(self):
-        for i in range(255):
+        for i in xrange(255):
             self.cpu.accu_a.set(i)
             t = self.cpu.accu_a.get()
             self.assertEqual(i, t)
@@ -192,7 +193,7 @@ class Test6809_CC(BaseCPUTestCase):
         self.assertEqual(status_byte, 0)
 
     def test_from_to(self):
-        for i in range(256):
+        for i in xrange(256):
             self.cpu.cc.set(i)
             status_byte = self.cpu.cc.get()
             self.assertEqual(status_byte, i)
@@ -202,7 +203,7 @@ class Test6809_CC(BaseCPUTestCase):
         excpected_values += list(range(0, 128))
         excpected_values += list(range(0, 4))
 
-        for i in range(260):
+        for i in xrange(260):
             self.cpu.accu_a.set(i)
             self.cpu.cc.set(0x0e) # Set affected flags: ....NZV.
             self.cpu_test_run(start=0x1000, end=None, mem=[
@@ -253,7 +254,7 @@ class Test6809_Ops(BaseCPUTestCase):
     def test_CMPU_immediate(self):
         u = 0x80
         self.cpu.user_stack_pointer.set(u)
-        for m in range(0x7e, 0x83):
+        for m in xrange(0x7e, 0x83):
             self.cpu_test_run(start=0x0000, end=None, mem=[
                 0x11, 0x83, # CMPU (immediate word)
                 0x00, m # the word that CMP reads
@@ -294,7 +295,7 @@ class Test6809_Ops(BaseCPUTestCase):
     def test_CMPA_immediate_byte(self):
         a = 0x80
         self.cpu.accu_a.set(a)
-        for m in range(0x7e, 0x83):
+        for m in xrange(0x7e, 0x83):
             self.cpu_test_run(start=0x0000, end=None, mem=[
                 0x81, m # CMPA (immediate byte)
             ])
@@ -337,7 +338,7 @@ class Test6809_Ops(BaseCPUTestCase):
     def test_CMPX_immediate_word(self):
         x = 0x80
         self.cpu.index_x.set(x)
-        for m in range(0x7e, 0x83):
+        for m in xrange(0x7e, 0x83):
             self.cpu_test_run(start=0x0000, end=None, mem=[
                 0x8c, 0x00, m # CMPX (immediate word)
             ])
@@ -415,7 +416,7 @@ class Test6809_TestInstructions(BaseCPUTestCase):
         self.assertEqual(self.cpu.cc.C, 1)
 
     def test_TST_direct(self):
-        for i in range(255):
+        for i in xrange(255):
             self.cpu.accu_a.set(i)
             self.cpu.cc.set(0xff) # Set all CC flags
 
@@ -427,7 +428,7 @@ class Test6809_TestInstructions(BaseCPUTestCase):
             self.assertTST(i)
 
     def test_TST_extended(self):
-        for i in range(255):
+        for i in xrange(255):
             self.cpu.accu_a.set(i)
             self.cpu.cc.set(0xff) # Set all CC flags
 
@@ -439,7 +440,7 @@ class Test6809_TestInstructions(BaseCPUTestCase):
             self.assertTST(i)
 
     def test_TSTA(self):
-        for i in range(255):
+        for i in xrange(255):
             self.cpu.accu_a.set(i)
             self.cpu.cc.set(0xff) # Set all CC flags
             self.cpu_test_run(start=0x1000, end=None, mem=[
@@ -448,7 +449,7 @@ class Test6809_TestInstructions(BaseCPUTestCase):
             self.assertTST(i)
 
     def test_TSTB(self):
-        for i in range(255):
+        for i in xrange(255):
             self.cpu.accu_b.set(i)
             self.cpu.cc.set(0xff) # Set all CC flags
             self.cpu_test_run(start=0x1000, end=None, mem=[
@@ -701,6 +702,8 @@ class TestSimple6809ROM(BaseCPUTestCase):
 
 
 if __name__ == '__main__':
+    from dragonlib.utils.logging_utils import setup_logging
+
     setup_logging(log,
 #         level=1 # hardcore debug ;)
 #        level=10 # DEBUG
